@@ -1,3 +1,5 @@
+# vim: tabstop=8 expandtab shiftwidth=4 softtabstop=4
+
 from .wiggle import Entity
 from fifo.helper import *
 
@@ -12,6 +14,9 @@ hypervisor_fmt = {
     'used':
     {'title': 'Used RAM', 'len': 10, 'fmt': "%10s",
      'get': lambda e: str(d(e, ['resources', 'provisioned-memory'])) + "MB"},
+    'reserved':
+    {'title': 'Reserved RAM', 'len': 10, 'fmt': "%10s",
+     'get': lambda e: str(d(e, ['resources', 'reserved-memory'])) + "MB"},
     'total':
     {'title': 'Total RAM', 'len': 10, 'fmt': "%10s",
      'get': lambda e: str(d(e, ['resources', 'total-memory'])) + "MB"},
@@ -32,6 +37,7 @@ class Hypervisor(Entity):
         parser_hypervisors = subparsers.add_parser('hypervisors', help='hypervisor related commands')
         parser_hypervisors.set_defaults(endpoint=self)
         subparsers_hypervisors = parser_hypervisors.add_subparsers(help='hypervisor commands')
+        self.add_metadata_parser(subparsers_hypervisors)
         parser_hypervisors_list = subparsers_hypervisors.add_parser('list', help='lists hypervisors')
         parser_hypervisors_list.add_argument("--fmt", action=ListAction,
                                              default=['uuid', 'name', 'free', 'used'])
